@@ -2,9 +2,9 @@
 
 # Copyright (C) 2016 Red Hat
 #
-# This file is part of wikitcms.
+# This file is part of python-wikitcms.
 #
-# wikitcms is free software; you can redistribute it and/or modify
+# python-wikitcms is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
@@ -20,16 +20,27 @@
 # Author: Adam Williamson <awilliam@redhat.com>
 
 # these are all kinda inappropriate for pytest patterns
-# pylint: disable=old-style-class, no-init, protected-access, no-self-use, unused-argument
+# pylint: disable=no-init, protected-access, no-self-use, unused-argument, too-many-arguments
 
-from __future__ import unicode_literals
+"""Tests for result.py."""
 
 import wikitcms.result as rs
 
+
 class TestResults:
     """Tests for find_results()."""
 
-    def _check_result(self, res, status=None, user=None, bugs=None, comment="", bot=False, transferred=False, comment_bugs=None):
+    def _check_result(
+        self,
+        res,
+        status=None,
+        user=None,
+        bugs=None,
+        comment="",
+        bot=False,
+        transferred=False,
+        comment_bugs=None,
+    ):
         if bugs is None:
             bugs = []
         if comment_bugs is None:
@@ -57,17 +68,22 @@ class TestResults:
 {{result |fail |  rené|372312 |9345671}}
 """
         results = rs.find_results(restext)
-        assert len(results) is 9
+        assert len(results) == 9
         self._check_result(results[0])
         self._check_result(results[1], status="pass")
         self._check_result(results[2], status="fail", user="adamwill")
-        self._check_result(results[3], status="warn", user="adamwill", bugs=['345234'])
-        self._check_result(results[4], status="pass", user="kparal", bugs=['6789032'], comment="<ref>Some comment.</ref>")
-        self._check_result(results[5], status="fail", bugs=['3456780'])
+        self._check_result(results[3], status="warn", user="adamwill", bugs=["345234"])
+        self._check_result(
+            results[4],
+            status="pass",
+            user="kparal",
+            bugs=["6789032"],
+            comment="<ref>Some comment.</ref>",
+        )
+        self._check_result(results[5], status="fail", bugs=["3456780"])
         self._check_result(results[6], status="pass", user="previous RC3 run", transferred=True)
         self._check_result(results[7], status="pass", user="coconut", bot=True)
-        self._check_result(results[8], status="fail", user="rené", bugs=['372312', '9345671'])
-
+        self._check_result(results[8], status="fail", user="rené", bugs=["372312", "9345671"])
 
     def test_find_results_old_template(self):
         """Various common forms of the old testresult template."""
@@ -79,13 +95,22 @@ class TestResults:
 {{testresult/warn|jlaska}}  <ref>NEEDS REVIEW - https://fedorahosted.org/pipermail/autoqa-results/2009-November/001966.html</ref>
 """
         results = rs.find_results(restext)
-        assert len(results) is 5
+        assert len(results) == 5
         self._check_result(results[0])
         self._check_result(results[1], status="pass", user="jlaska")
-        self._check_result(results[2], status="fail", user="jkeating", bugs=['517926'])
-        self._check_result(results[3], status="fail", user="jlaska", bugs=['533420'], comment="<ref>- broken dep: gnome-python2-gdl-2.25.3-12.fc12.i686 requires libgdl-1.so.2</ref>")
-        self._check_result(results[4], status="warn", user="jlaska", comment="<ref>NEEDS REVIEW - https://fedorahosted.org/pipermail/autoqa-results/2009-November/001966.html</ref>")
-
+        self._check_result(results[2], status="fail", user="jkeating", bugs=["517926"])
+        res3comm = (
+            "<ref>- broken dep: gnome-python2-gdl-2.25.3-12.fc12.i686 requires "
+            "libgdl-1.so.2</ref>"
+        )
+        self._check_result(
+            results[3], status="fail", user="jlaska", bugs=["533420"], comment=res3comm
+        )
+        res4comm = (
+            "<ref>NEEDS REVIEW - https://fedorahosted.org/pipermail/autoqa-results/"
+            "2009-November/001966.html</ref>"
+        )
+        self._check_result(results[4], status="warn", user="jlaska", comment=res4comm)
 
     def test_find_results_exclusions(self):
         """Test excluding example, 'transferred' and 'bot' results."""
@@ -96,11 +121,25 @@ class TestResults:
 {{result|pass|previous RC2 run}}
 {{result|pass|coconut|bot=true}}
 """
-        assert len(rs.find_results(restext)) is 3
-        assert len(rs.find_results(restext, transferred=False)) is 2
-        assert len(rs.find_results(restext, bot=False)) is 2
-        assert len(rs.find_results(restext, transferred=False, bot=False)) is 1
+        assert len(rs.find_results(restext)) == 3
+        assert len(rs.find_results(restext, transferred=False)) == 2
+        assert len(rs.find_results(restext, bot=False)) == 2
+        assert len(rs.find_results(restext, transferred=False, bot=False)) == 1
 
+    def test_find_results_statuses(self):
+        """Test filtering results by status."""
+        restext = """
+{{result|none}}
+{{result|pass}}
+{{result|fail|adamwill}}
+{{result|pass|coconut|bot=true}}
+{{result|warn|kparal}}
+{{result|warn|jlaska}}
+"""
+
+        assert len(rs.find_results(restext)) == 6
+        assert len(rs.find_results(restext, statuses=["pass", "fail"])) == 3
+        assert len(rs.find_results(restext, statuses=["pass", "warn"], bot=False)) == 3
 
     def test_find_results_page_extracts(self):
         """Various tests culled from real test pages, with messy text."""
@@ -159,7 +198,7 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 | Tier3
 """
         results = rs.find_results(f12text)
-        assert len(results) is 9
+        assert len(results) == 9
         for res in results[3:6]:
             self._check_result(res, status="pass", user="kparal")
         for res in results[6:8]:
@@ -184,11 +223,17 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 |-
 """
         results = rs.find_results(f16text)
-        assert len(results) is 6
-        self._check_result(results[0], status="pass", user="rmarko", comment="<ref>{{bz|744463}} Final blocker?\n</ref>", comment_bugs=set(['744463']))
-        for res in (results[1],results[2],results[4]):
+        assert len(results) == 6
+        self._check_result(
+            results[0],
+            status="pass",
+            user="rmarko",
+            comment="<ref>{{bz|744463}} Final blocker?\n</ref>",
+            comment_bugs=set(["744463"]),
+        )
+        for res in (results[1], results[2], results[4]):
             self._check_result(res, status="pass", user="rmarko")
-        for res in (results[3],results[5]):
+        for res in (results[3], results[5]):
             self._check_result(res, status="pass", user="robatino")
 
         # from Test_Results:Fedora_23_Final_RC3_Installation
@@ -216,8 +261,8 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 """
         results = rs.find_results(f23text)
         resexc = rs.find_results(f23text, bot=False)
-        assert len(results) is 11
-        assert len(resexc) is 5
+        assert len(results) == 11
+        assert len(resexc) == 5
         for res in (results[0], results[2], results[5], results[7], results[9], results[10]):
             self._check_result(res, status="pass", user="coconut", bot=True)
         for res in (results[3], results[8]):
@@ -227,8 +272,11 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
         self._check_result(results[4], status="pass", user="roshi")
 
     def test_find_results_by_row(self):
+        """Tests for find_results_by_row."""
         # extracts from Test_Day:2011-02-23_Radeon
         # example results (should be filtered), various username styles
+        # one result with a username included added to make coverage
+        # happy
         restext = """
 === Main tests ===
 
@@ -310,21 +358,24 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 | {{result|pass}}
 | {{result|pass}}
 | {{result|fail}} <ref>System didn't suspend successfully, it just simply switched off</ref>
+| {{result|warn|foobar}}
 | N/A
 | <references/>
 |-
 """
         results = rs.find_results_by_row(restext)
-        assert len(results) is 35
+        assert len(results) == 36
         for res in results[0:12]:
             assert res.user == "[[denis kurochkin]]"
         for res in results[12:24]:
             assert res.user == "madrouter"
         for res in results[24:34]:
             assert res.user == "mira"
+        assert results[35].user == "foobar"
 
-
-    def _check_resultrow(self, row, testcase, milestone, columns, results, section='', secid=0, name=None):
+    def _check_resultrow(
+        self, row, testcase, milestone, columns, results, section="", secid=0, name=None
+    ):
         assert row.testcase == testcase
         assert row.milestone == milestone
         assert row.columns == columns
@@ -337,7 +388,6 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
             name = testcase
         assert row.name == name
 
-
     def test_find_resultrows_simple(self):
         """find_resultrows: simple table."""
         text = """
@@ -368,12 +418,29 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 |}
 """
         rows = rs.find_resultrows(text)
-        assert len(rows) is 3
+        assert len(rows) == 3
         cols = ["Milestone", "Test Case", "x86 BIOS", "x86 UEFI", "ARM"]
-        self._check_resultrow(rows[0], "QA:Testcase_Install_to_Previous_KVM", "Beta", cols, {'x86 BIOS': 2, 'x86 UEFI': 1, 'ARM': 1})
-        self._check_resultrow(rows[1], "QA:Testcase_Install_to_Current_KVM", "Beta", cols, {'x86 BIOS': 1, 'x86 UEFI': 1, 'ARM': 1})
-        self._check_resultrow(rows[2], "QA:Testcase_Boot_Methods_Xen_Para_Virt", "Final", cols, {'x86 BIOS': 1, 'x86 UEFI': 1, 'ARM': 1})
-
+        self._check_resultrow(
+            rows[0],
+            "QA:Testcase_Install_to_Previous_KVM",
+            "Beta",
+            cols,
+            {"x86 BIOS": 2, "x86 UEFI": 1, "ARM": 1},
+        )
+        self._check_resultrow(
+            rows[1],
+            "QA:Testcase_Install_to_Current_KVM",
+            "Beta",
+            cols,
+            {"x86 BIOS": 1, "x86 UEFI": 1, "ARM": 1},
+        )
+        self._check_resultrow(
+            rows[2],
+            "QA:Testcase_Boot_Methods_Xen_Para_Virt",
+            "Final",
+            cols,
+            {"x86 BIOS": 1, "x86 UEFI": 1, "ARM": 1},
+        )
 
     def test_find_resultrows_names(self):
         """find_resultrows: test instances by name."""
@@ -402,15 +469,32 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 |-
 """
         rows = rs.find_resultrows(text)
-        assert len(rows) is 3
+        assert len(rows) == 3
         cols = ["Milestone", "Image", "i386", "x86_64", "UEFI"]
-        self._check_resultrow(rows[0], "QA:Testcase_Boot_default_install", "Alpha", cols,
-                              {'i386': 1, 'x86_64': 2, 'UEFI': 3}, name="Workstation live")
-        self._check_resultrow(rows[1], "QA:Testcase_Boot_default_install", "Alpha", cols,
-                              {'i386': 1, 'x86_64': 1, 'UEFI': 1}, name="Workstation netinst")
-        self._check_resultrow(rows[2], "QA:Testcase_Boot_default_install", "Alpha", cols,
-                              {'i386': 1, 'x86_64': 2, 'UEFI': 2}, name="Server netinst")
-
+        self._check_resultrow(
+            rows[0],
+            "QA:Testcase_Boot_default_install",
+            "Alpha",
+            cols,
+            {"i386": 1, "x86_64": 2, "UEFI": 3},
+            name="Workstation live",
+        )
+        self._check_resultrow(
+            rows[1],
+            "QA:Testcase_Boot_default_install",
+            "Alpha",
+            cols,
+            {"i386": 1, "x86_64": 1, "UEFI": 1},
+            name="Workstation netinst",
+        )
+        self._check_resultrow(
+            rows[2],
+            "QA:Testcase_Boot_default_install",
+            "Alpha",
+            cols,
+            {"i386": 1, "x86_64": 2, "UEFI": 2},
+            name="Server netinst",
+        )
 
     def test_find_resultrows_multiline(self):
         """find_resultrows: results split across lines."""
@@ -428,11 +512,14 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 |}
 """
         rows = rs.find_resultrows(text)
-        assert len(rows) is 1
-        self._check_resultrow(rows[0], "QA:Testcase_base_startup", "Alpha",
-                              ["Milestone", "Test Case", "Local", "EC2", "Openstack"],
-                              {'Local': 2, 'EC2': 1, 'Openstack': 2})
-
+        assert len(rows) == 1
+        self._check_resultrow(
+            rows[0],
+            "QA:Testcase_base_startup",
+            "Alpha",
+            ["Milestone", "Test Case", "Local", "EC2", "Openstack"],
+            {"Local": 2, "EC2": 1, "Openstack": 2},
+        )
 
     def test_find_resultrows_text_between_tables(self):
         """find_resultrows: check text containing test case names between
@@ -473,8 +560,7 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 |}
 """
         rows = rs.find_resultrows(text)
-        assert len(rows) is 2
-
+        assert len(rows) == 2
 
     def test_find_resultrows_column_titles_no_separator(self):
         """Test find_resultrows works OK when there is no separator
@@ -494,8 +580,15 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 |-
 """
         rows = rs.find_resultrows(text)
-        assert rows[0].columns == ['Priority', 'Test Area', 'Test Case', 'i386', 'ppc', 'x86_64', 'References']
-
+        assert rows[0].columns == [
+            "Priority",
+            "Test Area",
+            "Test Case",
+            "i386",
+            "ppc",
+            "x86_64",
+            "References",
+        ]
 
     def test_find_resultrows_column_titles_sanitize(self):
         """Test the cleanups find_resultrows does on column names."""
@@ -514,8 +607,114 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
 |-
 """
         rows = rs.find_resultrows(text)
-        assert rows[0].columns == ['Priority', 'Test Area', 'Test Case', 'i386', 'ppc', 'x86_64', 'References']
+        assert rows[0].columns == [
+            "Priority",
+            "Test Area",
+            "Test Case",
+            "i386",
+            "ppc",
+            "x86_64",
+            "References",
+        ]
 
+    def test_find_resultrows_iot(self):
+        """Test that find_resultrows works on the IoT test case names
+        that don't follow the same pattern as all the others.
+        """
+        text = """
+{| class="wikitable sortable mw-collapsible" border="1" width=100%
+! Milestone !! Test Case  !! x86_64 !! aarch64
+|-
+| Basic
+| [[User:Pwhalen/QA/IoT_Tests/Zezere_Ignition|Zezere Ignition]]
+| {{result|none}}
+| {{result|none}}
+|-
+| Basic
+| [[User:Pwhalen/QA/IoT_Tests/rpm-ostree_upgrade|rpm-ostree upgrade]]
+| {{result|none}}
+| {{result|none}}
+|-
+| Basic
+| [[User:Pwhalen/QA/IoT/RpmOstree_Package_Layering|Layered Package Installation]]
+| {{result|none}}
+| {{result|none}}
+|-
+| Basic
+| [[User:Pwhalen/QA/IoT_Tests/Rebase|rpm-ostree rebase]]
+| {{result|none}}
+| {{result|none}}
+|-
+| Basic
+| [[User:Pwhalen/QA/IoT_Tests/Podman_Basic|Podman]]
+| {{result|none}}
+| {{result|none}}
+|-
+| Basic
+| [[QA:Testcase_base_selinux]]
+| {{result|none}}
+| {{result|none}}
+|-
+| Basic
+| [[QA:Testcase_base_service_manipulation]]
+| {{result|none}}
+| {{result|none}}
+|-
+|}
+"""
+        rows = rs.find_resultrows(text)
+        assert len(rows) == 7
+        cols = ["Milestone", "Test Case", "x86_64", "aarch64"]
+        self._check_resultrow(
+            rows[0],
+            "User:Pwhalen/QA/IoT_Tests/Zezere_Ignition",
+            "Basic",
+            cols,
+            {"x86_64": 1, "aarch64": 1},
+            name="Zezere Ignition",
+        )
+        self._check_resultrow(
+            rows[1],
+            "User:Pwhalen/QA/IoT_Tests/rpm-ostree_upgrade",
+            "Basic",
+            cols,
+            {"x86_64": 1, "aarch64": 1},
+            name="rpm-ostree upgrade",
+        )
+        self._check_resultrow(
+            rows[2],
+            "User:Pwhalen/QA/IoT/RpmOstree_Package_Layering",
+            "Basic",
+            cols,
+            {"x86_64": 1, "aarch64": 1},
+            name="Layered Package Installation",
+        )
+        self._check_resultrow(
+            rows[3],
+            "User:Pwhalen/QA/IoT_Tests/Rebase",
+            "Basic",
+            cols,
+            {"x86_64": 1, "aarch64": 1},
+            name="rpm-ostree rebase",
+        )
+        self._check_resultrow(
+            rows[4],
+            "User:Pwhalen/QA/IoT_Tests/Podman_Basic",
+            "Basic",
+            cols,
+            {"x86_64": 1, "aarch64": 1},
+            name="Podman",
+        )
+        self._check_resultrow(
+            rows[5], "QA:Testcase_base_selinux", "Basic", cols, {"x86_64": 1, "aarch64": 1},
+        )
+        self._check_resultrow(
+            rows[6],
+            "QA:Testcase_base_service_manipulation",
+            "Basic",
+            cols,
+            {"x86_64": 1, "aarch64": 1},
+        )
 
     def test_result_string_template(self):
         """Test string representation and result_template of Result
@@ -532,12 +731,13 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
         assert str(res) == "Result: Fail from adamwill"
         assert res.result_template == "{{result|fail|adamwill}}"
 
-        # FIXME: use rené when py3 is merged
-        res = rs.Result(status="warn", user="rene", bugs=['435678', '1340987'])
-        assert str(res) == "Result: Warn from rene, bugs: 435678, 1340987"
-        assert res.result_template == "{{result|warn|rene|435678|1340987}}"
+        res = rs.Result(status="warn", user="rené", bugs=["435678", "1340987"])
+        assert str(res) == "Result: Warn from rené, bugs: 435678, 1340987"
+        assert res.result_template == "{{result|warn|rené|435678|1340987}}"
 
-        res = rs.Result(status="pass", user="kparal", comment="some comment <ref>some reference</ref>")
+        res = rs.Result(
+            status="pass", user="kparal", comment="some comment <ref>some reference</ref>"
+        )
         assert str(res) == "Result: Pass from kparal, comment: some comment some reference"
         assert res.result_template == "{{result|pass|kparal}}some comment <ref>some reference</ref>"
 
@@ -549,10 +749,17 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
         assert str(res) == "BOT Result: Pass from coconut"
         assert res.result_template == "{{result|pass|coconut|bot=true}}"
 
+    def test_from_result_template_bug_comment(self):
+        """Test from_result_template handling of bug numbers with
+        comment refs.
+        """
+        res = rs.Result.from_result_template("{{result|fail|bob|1034592#c8}}")
+        assert res.status == "fail"
+        assert res.user == "bob"
+        assert res.bugs == ["1034592"]
 
-    def test_resultrow_equality(self):
-        """Test the equality of ResultRows."""
-        # FIXME: on py3 this will be 'equals' method not a real ==
+    def test_resultrow_matches(self):
+        """Test the 'matches' method of ResultRows."""
         text = """
 {| class="wikitable sortable" border="1"
 |-
@@ -572,15 +779,19 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
         row1.secid = row2.secid = 1
         assert row1.matches(row2)
         row2.name = "foo"
-        assert row1 != row2
+        assert not row1.matches(row2)
         row2.name = row1.name
         row2.secid = 2
-        assert row1 != row2
+        assert not row1.matches(row2)
         row2.secid = row1.secid
         row2.origtext = "foo"
-        assert row1 != row2
+        assert not row1.matches(row2)
         row2.origtext = row1.origtext
         row2.testcase = "foo"
-        assert row1 != row2
+        assert not row1.matches(row2)
+        # test with a different type of object
+        notarow = "foo"
+        assert not row1.matches(notarow)
+
 
 # vim: set textwidth=100 ts=8 et sw=4:
